@@ -35,17 +35,20 @@ CLI_CONFIG = {
         "render": "cli",
         "subcommands": ["exec"],
     },
-    # State options
+    # State and validate options
+    "run_name": {
+        "subcommands": ["state", "exec", "describe", "validate"],
+    },
     "sls_sources": {"nargs": "*", "subcommands": ["state"]},
     "test": {"options": ["-t"], "action": "store_true", "subcommands": ["state"]},
     "tree": {
         "options": ["-T"],
-        "subcommands": ["state"],
+        "subcommands": ["state", "validate"],
     },
-    "cache_dir": {"subcommands": ["state"]},
-    "root_dir": {"subcommands": ["state"]},
+    "cache_dir": {"subcommands": ["state", "validate"]},
+    "root_dir": {"subcommands": ["state", "validate"]},
     "render": {
-        "subcommands": ["state"],
+        "subcommands": ["state", "validate"],
     },
     "runtime": {
         "subcommands": ["state"],
@@ -54,11 +57,15 @@ CLI_CONFIG = {
         "options": ["-r", "-R"],
         "subcommands": ["state"],
     },
+    "pending": {
+        "options": ["-p", "-P"],
+        "subcommands": ["state"],
+    },
     "output": {
         "source": "rend",
-        "subcommands": ["exec", "state", "describe", "decrypt"],
+        "subcommands": ["exec", "state", "describe", "decrypt", "validate"],
     },
-    "sls": {"positional": True, "nargs": "*", "subcommands": ["state"]},
+    "sls": {"positional": True, "nargs": "*", "subcommands": ["state", "validate"]},
     # ACCT options
     "input_file": {
         "source": "acct",
@@ -72,24 +79,33 @@ CLI_CONFIG = {
     "acct_file": {
         "source": "acct",
         "os": "ACCT_FILE",
-        "subcommands": ["state", "exec", "describe"],
+        "subcommands": ["state", "exec", "describe", "validate"],
     },
     "acct_key": {
         "source": "acct",
         "os": "ACCT_KEY",
-        "subcommands": ["state", "exec", "describe", "encrypt", "decrypt"],
+        "subcommands": ["state", "exec", "describe", "encrypt", "decrypt", "validate"],
     },
     "acct_profile": {
         "os": "ACCT_PROFILE",
-        "subcommands": ["state", "exec", "describe"],
+        "subcommands": ["state", "exec", "describe", "validate"],
     },
     "crypto_plugin": {
         "source": "acct",
         "subcommands": ["encrypt", "decrypt"],
     },
+    # EVBUS options
+    "serialize_plugin": {
+        "source": "evbus",
+        "subcommands": ["exec", "describe", "state", "validate"],
+    },
 }
 
 CONFIG = {
+    "run_name": {
+        "default": "cli",
+        "help": "A unique ID to assign to this run",
+    },
     "sls_sources": {
         "default": [],
         "help": "list off the sources that should be used for gathering sls files and data",
@@ -116,7 +132,7 @@ CONFIG = {
     },
     "runtime": {
         "default": "parallel",
-        "help": "Select which execution runtime to use",
+        "help": "Select which execution runtime to use. Options: 'parallel' (default), 'serial'.",
     },
     "sls": {
         "default": [],
@@ -139,6 +155,10 @@ CONFIG = {
         "default": "none",
         "help": "The reconciler plugin to use, 'none' by default",
     },
+    "pending": {
+        "default": "default",
+        "help": "The pending plugin to use within the reconciler, 'default' by default",
+    },
 }
 SUBCOMMANDS = {
     "encrypt": {
@@ -163,6 +183,10 @@ SUBCOMMANDS = {
         "desc": "Get an SLS representation of the account",
         "help": "Commands to run description routines",
     },
+    "validate": {
+        "desc": "Validate the given SLS tree and return the internal working data for the tree",
+        "help": "COmmands to validate SLS files",
+    },
 }
 DYNE = {
     "idem": ["idem"],
