@@ -4,9 +4,15 @@ from typing import Awaitable
 from idem.exec.init import ExecReturn
 
 
-def _create_exec_return(ret, ref: str):
+def _create_exec_return(hub, ret, ref: str):
     if isinstance(ret, ExecReturn):
         return ret
+    hub.idem.event.put_nowait(
+        routing_key=hub.idem.RUN_NAME,
+        body=ret,
+        profile="idem-exec",
+        tags={"ref": ref, "type": "exec-post"},
+    )
     try:
         return ExecReturn(
             **ret,
@@ -21,15 +27,15 @@ def _create_exec_return(ret, ref: str):
 
 async def _create_exec_return_coro(hub, ret: Awaitable, ref: str):
     ret = await hub.pop.loop.unwrap(ret)
-    return _create_exec_return(ret, ref)
+    return _create_exec_return(hub, ret, ref)
 
 
 def post(hub, ctx):
     """
     Convert the dict return to an immutable namespace addressable format
     """
-    ref = ctx.func.__module__
+    ref = f"{ctx.ref}.{ctx.func.__name__}"
     if asyncio.iscoroutine(ctx.ret):
         return _create_exec_return_coro(hub, ctx.ret, ref)
     else:
-        return _create_exec_return(ctx.ret, ref)
+        return _create_exec_return(hub, ctx.ret, ref)
