@@ -57,7 +57,13 @@ async def run(
     if progress:
         progress_bar.close()
     if search_path:
-        return jmespath.search(search_path, result)
+        prepped = hub.output.jmespath.prepare(result)
+        searched = jmespath.search(search_path, prepped)
+        if hub.OPT.rend.get("output") == "jmespath":
+            # Don't post-process the result, it's already in jmespath format
+            return searched
+        else:
+            return hub.output.jmespath.revert(searched)
     return result
 
 
@@ -99,21 +105,22 @@ async def recurse(
 
                     coro = _async_desc()
                 yield hub.pop.Loop.create_task(coro)
-        elif hasattr(mod, "_funcs") and "describe" in mod._funcs:
-            # TODO Raise an error here instead of a warning
-            warnings.warn(
-                f"Running 'describe' without implementing the `resource` contract for {mod} is deprecated.\n"
-                "Implement the resource contract for this mod for it to continue functioning in future releases.\n"
-                "__contracts__ = ['resource']",
-                DeprecationWarning,
-            )
-            if fnmatch.fnmatch(ref, glob):
-                if isinstance(mod.describe, pop.contract.ContractedAsync):
-                    coro = mod.describe(ctx)
-                else:
 
-                    async def _async_desc():
-                        return mod.describe(ctx)
+    if hasattr(mod, "_funcs") and "describe" in mod._funcs:
+        # TODO Raise an error here instead of a warning
+        warnings.warn(
+            f"Running 'describe' without implementing the `resource` contract for {mod} is deprecated.\n"
+            "Implement the resource contract for this mod for it to continue functioning in future releases.\n"
+            "__contracts__ = ['resource']",
+            DeprecationWarning,
+        )
+        if fnmatch.fnmatch(ref, glob):
+            if isinstance(mod.describe, pop.contract.ContractedAsync):
+                coro = mod.describe(ctx)
+            else:
 
-                    coro = _async_desc()
-                yield hub.pop.Loop.create_task(coro)
+                async def _async_desc():
+                    return mod.describe(ctx)
+
+                coro = _async_desc()
+            yield hub.pop.Loop.create_task(coro)
