@@ -18,6 +18,7 @@ def __init__(hub):
     hub.pop.sub.add(dyne_name="acct")
     hub.pop.sub.add(dyne_name="rend")
     hub.pop.sub.add(dyne_name="output")
+    hub.pop.sub.add(dyne_name="evbus")
     hub.pop.sub.add(dyne_name="reconcile")
     hub.pop.sub.load_subdirs(hub.reconcile, recurse=True)
     hub.pop.sub.add(dyne_name="tool")
@@ -27,13 +28,14 @@ def __init__(hub):
     hub.pop.sub.add(dyne_name="states")
     hub.pop.sub.load_subdirs(hub.states, recurse=True)
     hub.idem.req.init.req_map()
+    hub.idem.RUN_NAME = "cli"
 
 
 def cli(hub):
     """
     Execute a single idem run from the cli
     """
-    hub.pop.config.load(["idem", "acct", "rend"], cli="idem")
+    hub.pop.config.load(["idem", "acct", "rend", "evbus"], cli="idem")
     hub.pop.loop.create()
     retcode = hub.pop.Loop.run_until_complete(hub.idem.init.cli_apply())
     sys.exit(retcode)
@@ -60,7 +62,7 @@ def get_refs(hub):
         else:
             slses.append(sls)
 
-    sls_sources.extend(hub.OPT["idem"]["sls_sources"])
+    sls_sources.extend(hub.OPT.idem.sls_sources)
 
     return {"sls_sources": sls_sources, "sls": slses}
 
@@ -70,18 +72,44 @@ async def cli_apply(hub):
     Run the CLI routine in a loop
     """
     if hub.SUBPARSER in ("encrypt", "decrypt"):
-        retcode = await hub.acct.init.cli_apply()
-    elif hub.SUBPARSER == "state":
-        retcode = await hub.idem.init.cli_sls()
-    elif hub.SUBPARSER == "exec":
-        retcode = await hub.idem.init.cli_exec()
-    elif hub.SUBPARSER == "describe":
-        retcode = await hub.idem.init.cli_desc()
-    else:
-        print(hub.args.parser.help())
-        retcode = 2
+        # Break early for acct commands
+        return await hub.acct.init.cli_apply()
 
-    return retcode
+    # Initialize the broker queue for evbus
+    await hub.evbus.broker.init()
+
+    # Specify the serializing plugin for evbus
+    hub.serialize.PLUGIN = hub.OPT.evbus.serialize_plugin
+    # Use the run name as a routing key for exec modules
+    hub.idem.RUN_NAME = hub.OPT.idem.run_name
+
+    # Collect ingress profiles from acct
+    ingress_profiles = await hub.evbus.acct.profiles(
+        acct_file=hub.OPT.acct.acct_file,
+        acct_key=hub.OPT.acct.acct_key,
+    )
+
+    # Start the listener in it's own task
+    listener = hub.pop.Loop.create_task(hub.evbus.init.start(ingress_profiles))
+    await hub.evbus.init.join()
+
+    try:
+        await hub.evbus.init.join()
+        # Only allow one instance of "run_name" at a time
+        if hub.SUBPARSER == "state":
+            return await hub.idem.init.cli_sls()
+        elif hub.SUBPARSER == "exec":
+            return await hub.idem.init.cli_exec()
+        elif hub.SUBPARSER == "describe":
+            return await hub.idem.init.cli_desc()
+        elif hub.SUBPARSER == "validate":
+            return await hub.idem.init.cli_validate()
+        else:
+            print(hub.args.parser.help())
+            return 2
+    finally:
+        await hub.evbus.init.stop()
+        await listener
 
 
 async def cli_sls(hub) -> int:
@@ -89,7 +117,7 @@ async def cli_sls(hub) -> int:
     Execute the cli routine to run states
     """
     src = hub.idem.init.get_refs()
-    name = "cli"
+    name = hub.OPT.idem.run_name
     await hub.idem.state.apply(
         name=name,
         sls_sources=src["sls_sources"],
@@ -114,6 +142,7 @@ async def cli_sls(hub) -> int:
     # Reconciliation loop
     await hub.reconcile.init.run(
         plugin=hub.OPT.idem.reconciler,
+        pending_plugin=hub.OPT.idem.pending,
         name=name,
         sls_sources=src["sls_sources"],
         render=hub.OPT.idem.render,
@@ -180,3 +209,41 @@ async def cli_desc(hub) -> int:
     display = hub.output[output].display(ret)
     print(display)
     return 0
+
+
+async def cli_validate(hub) -> int:
+    """
+    Execute the cli routine to validate states
+    """
+    src = hub.idem.init.get_refs()
+    name = hub.OPT.idem.run_name
+    await hub.idem.state.validate(
+        name=name,
+        sls_sources=src["sls_sources"],
+        render=hub.OPT.idem.render,
+        runtime=hub.OPT.idem.runtime,
+        subs=["states"],
+        cache_dir=hub.OPT.idem.cache_dir,
+        sls=src["sls"],
+        test=hub.OPT.idem.test,
+        acct_file=hub.OPT.acct.acct_file,
+        acct_key=hub.OPT.acct.acct_key,
+        acct_profile=hub.OPT.idem.acct_profile,
+    )
+
+    errors = hub.idem.RUNS[name]["errors"]
+    if errors:
+        display = hub.output.nested.display(errors)
+        print(display)
+        # Return a non-zero error code
+        return len(errors)
+
+    ret = {
+        "high": hub.idem.RUNS[name]["high"],
+        "low": hub.idem.RUNS[name]["low"],
+        "meta": hub.idem.RUNS[name]["meta"],
+    }
+    output = hub.OPT.rend.output or "nested"
+    display = hub.output[output].display(ret)
+    print(display)
+    return 0
