@@ -17,6 +17,12 @@ async def modify(hub, name, chunk):
         subs = getattr(hub, f"tool.{state}.ACCT")
     hub.log.debug(f"Loaded acct from subs: {subs}")
     profile = chunk.pop("acct_profile", hub.idem.RUNS[run_name]["acct_profile"])
+    acct_data = chunk.pop("acct_profile", hub.idem.RUNS[run_name]["acct_data"])
+
     hub.log.debug(f"Loaded profile: {profile}")
-    chunk["ctx"]["acct"] = await hub.acct.init.gather(subs, profile)
+    chunk["ctx"]["acct"] = await hub.acct.init.gather(
+        subs,
+        profile,
+        profiles=acct_data.get("profiles"),
+    )
     return chunk
