@@ -5,6 +5,7 @@ downloading those sls files and then rendering them.
 
 Once an sls file is rendered the include statements are resolved as well.
 """
+import copy
 import re
 
 
@@ -12,31 +13,37 @@ async def gather(hub, name, *sls):
     """
     Gather the named sls references
     """
-    await hub.idem.resolve.get_blocks(name, sls)
+    result = await hub.idem.resolve.get_blocks(name, sls)
+    if not result:
+        return
+
     await hub.idem.resolve.render(name)
 
 
 async def get_blocks(hub, name, sls):
+    # Returns 'False' if the SLS file cannot be found
     for sls_ref in sls:
         cfn = await hub.idem.get.ref(name, sls_ref)
         if not cfn:
-            hub.idem.RUNS[name]["errors"].append(
-                f"SLS ref {sls_ref} did not resolve to a file"
-            )
-            continue
+            msg = f"SLS ref {sls_ref} did not resolve to a file"
+            hub.log.debug(msg)
+            hub.idem.RUNS[name]["errors"].append(msg)
+            return False
         blocks = hub.rend.init.blocks(cfn)
         hub.idem.RUNS[name]["blocks"][sls_ref] = blocks
         hub.idem.RUNS[name]["sls_refs"][sls_ref] = cfn
         hub.idem.RUNS[name]["resolved"].add(sls_ref)
         hub.idem.RUNS[name]["files"].add(cfn)
 
+    return True
+
 
 async def render(hub, name):
     """
     Pop the available blocks and render them if they have satisfied requisites
     """
     rendered = {}
-    for sls_ref, blocks in hub.idem.RUNS[name]["blocks"].items():
+    for sls_ref, blocks in copy.deepcopy(list(hub.idem.RUNS[name]["blocks"].items())):
         cfn = hub.idem.RUNS[name]["sls_refs"][sls_ref]
         for bname, block in blocks.items():
             clear = True
@@ -59,7 +66,7 @@ async def render(hub, name):
                 await hub.idem.resolve.introduce(name, state, sls_ref, cfn)
                 rendered[sls_ref] = bname
     for sls_ref, bname in rendered.items():
-        hub.idem.RUNS[name]["blocks"][sls_ref].pop(bname)
+        hub.idem.RUNS[name]["blocks"][sls_ref].pop(bname, None)
 
 
 async def introduce(hub, name, state, sls_ref, cfn):
@@ -84,7 +91,13 @@ async def introduce(hub, name, state, sls_ref, cfn):
     hub.idem.resolve.exclude(name, state, sls_ref)
     hub.idem.resolve.decls(name, state, sls_ref)
     hub.idem.resolve.iorder(name, state)
-    await hub.idem.resolve.includes(name, include, state, sls_ref, cfn)
+    await hub.idem.resolve.includes(name, include, sls_ref, cfn)
+    await hub.idem.event.put(
+        routing_key=name,
+        profile="idem-high",
+        body=state,
+        tags={"type": "state-high-data", "ref": "idem.resolve.introduce"},
+    )
     hub.idem.RUNS[name]["high"].update(state)
 
 
@@ -156,10 +169,15 @@ def extend(hub, name, state, sls_ref):
 
 
 def meta(hub, name, state, sls_ref):
-    if "META" not in state:
-        return
-    raw_meta = state.pop("META")
-    hub.idem.RUNS[name]["meta"][sls_ref] = raw_meta
+    if "META" in state:
+        raw_meta = state.pop("META")
+        hub.idem.RUNS[name]["meta"]["SLS"][sls_ref] = raw_meta
+    for id_ in state:
+        if isinstance(state[id_], dict):
+            if "META" in state[id_]:
+                ref = f"{sls_ref}.{id_}"
+                raw_meta = state[id_].pop("META")
+                hub.idem.RUNS[name]["meta"]["ID_DECS"][ref] = raw_meta
 
 
 def exclude(hub, name, state, sls_ref):
@@ -229,7 +247,7 @@ def decls(hub, name, state, sls_ref):
             state[id_]["__sls__"] = sls_ref
 
 
-async def includes(hub, name, include, state, sls_ref, cfn):
+async def includes(hub, name, include, sls_ref, cfn):
     """
     Parse through the includes and download not-yet-resolved includes
     """
@@ -254,4 +272,4 @@ async def includes(hub, name, include, state, sls_ref, cfn):
                 continue
             inc_sls = ".".join(p_comps[:-level_count] + [include])
         if inc_sls not in hub.idem.RUNS[name]["resolved"]:
-            await hub.idem.sls.resolve.gather(name, inc_sls)
+            await hub.idem.resolve.gather(name, inc_sls)
