@@ -2,7 +2,7 @@ import pop.loader
 
 
 # These are keywords passed to state module functions which are to be used
-# by salt in this state module and not on the actual state module function
+# by idem in this state module and not on the actual state module function
 STATE_REQUISITE_KEYWORDS = frozenset(
     [
         "onchanges",
@@ -18,6 +18,7 @@ STATE_REQUISITE_KEYWORDS = frozenset(
         "require",
         "require_any",
         "listen",
+        "arg_bind",
     ]
 )
 STATE_REQUISITE_IN_KEYWORDS = frozenset(
@@ -138,6 +139,12 @@ async def run(hub, name, ctx, low, seq_comp, running, run_num):
         }
         return
     func = hub.idem.rules.init.get_func(name, chunk)
+    await hub.idem.event.put(
+        routing_key=name,
+        profile="idem-chunk",
+        body=chunk,
+        tags={"ref": "idem.rules.init.run", "type": "state-chunk"},
+    )
     if func is None:
         running[tag] = {
             "name": chunk["name"],
