@@ -12,6 +12,13 @@ async def start(hub, name):
 
     rtime = hub.idem.RUNS[name]["runtime"]
     low = hub.idem.RUNS[name].get("low")
+    # Fire an event with all the pre-rendered low-data for all states
+    await hub.idem.event.put(
+        routing_key=name,
+        profile="idem-low",
+        body=low,
+        tags={"ref": "idem.run.init.start", "type": "state-low-data"},
+    )
     ref = f"idem.run.{rtime}.runtime"
     old_seq = {}
     old_seq_len = -1
@@ -25,6 +32,12 @@ async def start(hub, name):
         await hub.idem.resolve.render(name)
         await hub.idem.state.compile(name)
         low = hub.idem.RUNS[name].get("low")
+        await hub.idem.event.put(
+            routing_key=name,
+            profile="idem-low",
+            body=low,
+            tags={"ref": "idem.run.init.start", "type": "state-low-data"},
+        )
         if len(low) <= len(hub.idem.RUNS[name]["running"]):
             if hub.idem.RUNS[name]["post_low"] and needs_post_low:
                 hub.idem.RUNS[name]["low"].extend(hub.idem.RUNS[name]["post_low"])
