@@ -206,3 +206,52 @@ def iter_high(hub, high):
                 continue
             for arg in run:
                 yield id_, body, state, run, arg
+
+
+def iter_high_leaf_args(hub, high):
+    """
+    Take a highstate strucutre and iterate over it yielding the elements down to the
+    execution args
+    Yields (id_, body, state, run, arg)
+    """
+    for id_, body in high.items():
+        if not isinstance(body, dict):
+            continue
+        for state, run in body.items():
+            if state.startswith("__"):
+                continue
+            for arg in run:
+                yield from _iter_arg_chain(id_, body, state, run, "", arg)
+
+
+def _iter_arg_chain(id_, body, state, run, arg_key_def, arg):
+    if isinstance(arg, dict):
+        for arg_key, arg_value in arg.items():
+            if arg_key_def:
+                current_arg_key_def = arg_key_def + ":" + arg_key
+            else:
+                current_arg_key_def = arg_key
+
+            if isinstance(arg_value, dict):
+                yield from _iter_arg_chain(
+                    id_, body, state, run, current_arg_key_def, arg_value
+                )
+            elif isinstance(arg_value, list):
+                for index, arg_value_item in enumerate(arg_value):
+                    yield from _iter_arg_chain(
+                        id_,
+                        body,
+                        state,
+                        run,
+                        current_arg_key_def + f"[{index}]",
+                        arg_value_item,
+                    )
+            else:
+                yield id_, body, state, run, current_arg_key_def, arg_value
+    elif isinstance(arg, list):
+        for index, arg_value_item in enumerate(arg):
+            yield from _iter_arg_chain(
+                id_, body, state, run, arg_key_def + f"[{index}]", arg_value_item
+            )
+    else:
+        yield id_, body, state, run, arg_key_def, arg
