@@ -1,5 +1,9 @@
+from typing import List
+
+
 async def loop(
     hub,
+    pending_plugin,
     name,
     sls_sources,
     render,
@@ -7,9 +11,11 @@ async def loop(
     cache_dir,
     sls,
     test,
-    acct_file,
-    acct_key,
-    acct_profile,
+    acct_file: str = None,
+    acct_key: str = None,
+    acct_profile: str = None,
+    acct_blob: str = None,
+    subs: List[str] = None,
 ):
     # This is the default reconciler
     # Reconciliation loop is skipped for backward compatibility
