@@ -5,11 +5,9 @@ def sig_get(hub, **kwargs):
     ...
 
 
-def post_get(self, hub):
+def post_get(hub, ctx):
     """
     Conform the return value of every reconcile.wait get()
     """
-    try:
-        assert isinstance(hub.ret, int)
-    except KeyError:
-        hub.log.error("reconcile.wait plugins wait functions should return integers")
+    assert isinstance(ctx.ret, int)
+    return ctx.ret
