@@ -119,12 +119,48 @@ def succeed_with_changes(hub, ctx, name, **kwargs):
     name:
         A unique string.
     """
-    ret = {"name": name, "changes": {}, "result": True, "comment": "Success!"}
+    ret = {
+        "name": name,
+        "old_state": {},
+        "new_state": {},
+        "changes": {},
+        "result": True,
+        "comment": "Success!",
+    }
 
     ret["changes"] = {
-        "testing": {"old": "Unchanged", "new": "Something pretended to change"}
+        "testing": {"old": "Unchanged", "new": "Something pretended to change"},
+        "tests": [[{"new": "new_test"}]],
     }
 
+    ret["new_state"] = {
+        "testing": {"old": "Unchanged", "new": "Something pretended to change"},
+        "tests": [[{"new": "new_test"}]],
+    }
+
+    return ret
+
+
+def succeed_with_arg_bind(hub, ctx, name, **kwargs):
+    """
+    Returns successful and changes is not empty
+
+    name:
+        A unique string.
+    """
+    ret = {
+        "name": name,
+        "old_state": {},
+        "new_state": {},
+        "changes": {},
+        "result": True,
+        "comment": "Success!",
+    }
+
+    ret["changes"] = {"testing": kwargs.get("parameters", {})}
+
+    ret["new_state"] = {"testing": kwargs.get("parameters", {})}
+
     return ret
 
 
@@ -236,7 +272,7 @@ async def describe(hub, ctx):
     ret = {}
     for func in hub.states.test:
         name = func.__name__
-        if name in ("present", "absent"):
+        if name in ("present", "absent", "succeed_with_arg_bind"):
             continue
         ref = f"test.{name}"
         state_name = f"Description of {ref}"
